@@ -1,5 +1,9 @@
 //! Everything about parsing text into text annotated with scopes.
-//! The most important struct here is `SyntaxSet`, check out the docs for that.
+//!
+//! The most important struct here is [`SyntaxSet`], check out the docs for that.
+//!
+//! [`SyntaxSet`]: struct.SyntaxSet.html
+
 #[cfg(feature = "metadata")]
 pub mod metadata;
 #[cfg(feature = "parsing")]
@@ -12,6 +16,8 @@ mod syntax_set;
 mod yaml_load;
 
 mod scope;
+#[cfg(any(feature = "parsing", feature = "yaml-load", feature = "metadata"))]
+mod regex;
 
 #[cfg(feature = "parsing")]
 pub use self::syntax_definition::SyntaxDefinition;
@@ -24,4 +30,7 @@ pub use self::parser::*;
 #[cfg(feature = "metadata")]
 pub use self::metadata::*;
 
+#[cfg(any(feature = "parsing", feature = "yaml-load", feature = "metadata"))]
+pub use self::regex::*;
+
 pub use self::scope::*;
